==> mktcenter-service-1.0.2-20190605.053704-88-sources.jar: com/bizvane/mktcenterservice/interfaces/MktGiftBagService.java <==
package com.bizvane.mktcenterservice.interfaces;

import com.bizvane.couponfacade.models.po.CouponDefinitionPO;
import com.bizvane.mktcenterservice.models.bo.ActivityGiftbagBO;
import com.bizvane.mktcenterservice.models.po.MktCouponPO;
import com.bizvane.mktcenterservice.models.po.MktGiftBagPO;
import com.bizvane.mktcenterservice.models.vo.MktGiftBagVO;
import com.bizvane.mktcenterservice.models.vo.PageForm;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;
import com.github.pagehelper.PageInfo;

/**
 * @Author: lijunwei
 * @Time: 2019/4/25 11:18
 */
public interface MktGiftBagService {
    public ResponseData<Integer> insertGiftBag(ActivityGiftbagBO activityGiftbagBO, SysAccountPO sysAccountPo);

    public ResponseData<Integer> updateGiftBag(ActivityGiftbagBO activityGiftbagBO, SysAccountPO sysAccountPo);

    public ResponseData<Integer> updateGiftBagStatus(MktGiftBagPO mktGiftBagPO, SysAccountPO sysAccountPo);

    public ResponseData<ActivityGiftbagBO> selectGiftBagDetail(MktGiftBagPO mktGiftBagPO, SysAccountPO sysAccountPo);

    public ResponseData<PageInfo<MktGiftBagPO>> searchGiftBagList(MktGiftBagPO mktGiftBagPO, PageForm pageForm, SysAccountPO sysAccountPo);

    public ResponseData<PageInfo<ActivityGiftbagBO>> selectGiftBagList(MktGiftBagPO mktGiftBagPO, PageForm pageForm, SysAccountPO sysAccountPo);

    public ResponseData<PageInfo<MktGiftBagVO>> selectGiftBagListNew(MktGiftBagPO mktGiftBagPO, PageForm pageForm, SysAccountPO sysAccountPo);

}

==> mktcenter-service-2.2.10-20221226.085400-2-sources.jar: com/bizvane/mktcenterservice/interfaces/MktGiftBagService.java <==
package com.bizvane.mktcenterservice.interfaces;

import com.bizvane.couponfacade.models.po.CouponDefinitionPO;
import com.bizvane.mktcenterservice.models.bo.ActivityGiftbagBO;
import com.bizvane.mktcenterservice.models.po.MktCouponPO;
import com.bizvane.mktcenterservice.models.po.MktGiftBagPO;
import com.bizvane.mktcenterservice.models.vo.MktGiftBagVO;
import com.bizvane.mktcenterservice.models.vo.PageForm;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;
import com.github.pagehelper.PageInfo;

/**
 * @Author: lijunwei
 * @Time: 2019/4/25 11:18
 */
public interface MktGiftBagService {
    public ResponseData<Integer> insertGiftBag(ActivityGiftbagBO activityGiftbagBO, SysAccountPO sysAccountPo);

    public ResponseData<Integer> updateGiftBag(ActivityGiftbagBO activityGiftbagBO, SysAccountPO sysAccountPo);

    public ResponseData<Integer> updateGiftBagStatus(MktGiftBagPO mktGiftBagPO, SysAccountPO sysAccountPo);

    public ResponseData<ActivityGiftbagBO> selectGiftBagDetail(MktGiftBagPO mktGiftBagPO, SysAccountPO sysAccountPo);

    public ResponseData<PageInfo<MktGiftBagPO>> searchGiftBagList(MktGiftBagPO mktGiftBagPO, PageForm pageForm, SysAccountPO sysAccountPo);

    public ResponseData<PageInfo<ActivityGiftbagBO>> selectGiftBagList(MktGiftBagPO mktGiftBagPO, PageForm pageForm, SysAccountPO sysAccountPo);

    public ResponseData<PageInfo<MktGiftBagVO>> selectGiftBagListNew(MktGiftBagPO mktGiftBagPO, PageForm pageForm, SysAccountPO sysAccountPo);

    ResponseData<ActivityGiftbagBO> selectGiftBagDetailForCounpon(MktGiftBagPO mktGiftBagPO);

    ResponseData<MktGiftBagPO> selectGiftBagByGiftBagId(Long mktGiftBagId);
}
